% calculate results found in paper

TIMEOUT = 600;

%load data
D = load('cogsci10_speededUnspeeded_dataset.csv');

sids = unique(D(:,2));

% block and grid indexes
b1 = [1:100];
b2 = [101:200];
b3 = [201:300];
b4 = [301:400];
grid = [401:436];

blockAcc = [];  % holds condition number and block accuracies for each subject
countAcc = [];

for i = 1:length(sids)

  sid = sids(i);

  S = D(find(D(:,2) == sid),:);
  c = unique(S(:,1));
  if length(c) ~= 1
    fprintf('ERROR more than one condition for subject %d\n',sid);
  end

  if c == 1 | c == 2

    p1 = length(find((S(b1,5) == -1 & S(b1,6) == -1)  | (S(b1,5) == 1 & S(b1,6) == 1)))/length(find(S(b1,5) ~= 0));
    p2 = length(find((S(b2,5) == -1 & S(b2,6) == -1)  | (S(b2,5) == 1 & S(b2,6) == 1)))/length(find(S(b2,5) ~= 0));
    p3 = length(find((S(b3,5) == -1 & S(b3,6) == -1)  | (S(b3,5) == 1 & S(b3,6) == 1)))/length(find(S(b3,5) ~= 0));
    p4 = length(find((S(b4,5) == -1 & S(b4,6) == -1)  | (S(b4,5) == 1 & S(b4,6) == 1)))/length(find(S(b4,5) ~= 0));
    pGrid = length(find((S(grid,5) == -1 & S(grid,6) == -1) | (S(grid,5) == 1 & S(grid,6) == 1)))/length(grid);

  else

    p1 = length(find(S(b1,7) ~= TIMEOUT & (S(b1,5) == -1 & S(b1,6) == -1)  | (S(b1,5) == 1 & S(b1,6) == 1)))/length(find(S(b1,5) ~= 0 & S(b1,7) ~= TIMEOUT));
    p2 = length(find(S(b2,7) ~= TIMEOUT & (S(b2,5) == -1 & S(b2,6) == -1)  | (S(b2,5) == 1 & S(b2,6) == 1)))/length(find(S(b2,5) ~= 0 & S(b2,7) ~= TIMEOUT));
    p3 = length(find(S(b3,7) ~= TIMEOUT & (S(b3,5) == -1 & S(b3,6) == -1)  | (S(b3,5) == 1 & S(b3,6) == 1)))/length(find(S(b3,5) ~= 0 & S(b3,7) ~= TIMEOUT));
    p4 = length(find(S(b4,7) ~= TIMEOUT & (S(b4,5) == -1 & S(b4,6) == -1)  | (S(b4,5) == 1 & S(b4,6) == 1)))/length(find(S(b4,5) ~= 0 & S(b4,7) ~= TIMEOUT));
    pGrid = length(find(S(grid,7) ~= TIMEOUT & (S(grid,5) == -1 & S(grid,6) == -1) | (S(grid,5) == 1 & S(grid,6) == 1)))/length(find(S(grid,7) ~= TIMEOUT));

  end

  blockAcc(end+1,:) = [c,p1,p2,p3,p4,pGrid];

  if c == 1 | 2

    c1 = length(find((S(b1,5) == -1 & S(b1,6) == -1)  | (S(b1,5) == 1 & S(b1,6) == 1)));
    c2 = length(find((S(b2,5) == -1 & S(b2,6) == -1)  | (S(b2,5) == 1 & S(b2,6) == 1)));
    c3 = length(find((S(b3,5) == -1 & S(b3,6) == -1)  | (S(b3,5) == 1 & S(b3,6) == 1)));
    c4 = length(find((S(b4,5) == -1 & S(b4,6) == -1)  | (S(b4,5) == 1 & S(b4,6) == 1)));
    cGrid = length(find((S(grid,5) == -1 & S(grid,6) == -1) | (S(grid,5) == 1 & S(grid,6) == 1)));

  else

    c1 = length(find(S(b1,7) ~= TIMEOUT & (S(b1,5) == -1 & S(b1,6) == -1)  | (S(b1,5) == 1 & S(b1,6) == 1)));
    c2 = length(find(S(b2,7) ~= TIMEOUT & (S(b2,5) == -1 & S(b2,6) == -1)  | (S(b2,5) == 1 & S(b2,6) == 1)));
    c3 = length(find(S(b3,7) ~= TIMEOUT & (S(b3,5) == -1 & S(b3,6) == -1)  | (S(b3,5) == 1 & S(b3,6) == 1)));
    c4 = length(find(S(b4,7) ~= TIMEOUT & (S(b4,5) == -1 & S(b4,6) == -1)  | (S(b4,5) == 1 & S(b4,6) == 1)));
    cGrid = length(find(S(grid,7) ~= TIMEOUT & (S(grid,5) == -1 & S(grid,6) == -1) | (S(grid,5) == 1 & S(grid,6) == 1)));

  end

  countAcc(end+1,:) = [c,c1,c2,c3,c4,cGrid];
end 

for i = 1:4

  accMeans(i,:) = mean(blockAcc(find(blockAcc(:,1) == i),[2:end]));
  accStderrs(i,:) = std(blockAcc(find(blockAcc(:,1) == i),[2:end]))./sqrt(25);
  learners = find(blockAcc(:,1) == i & blockAcc(:,6) > .66);
  numLearners(i) = length(learners);
  learnerAccMeans(i,:) = mean(blockAcc(learners,[2:end-1]));
  learnerAccStderrs(i,:) = std(blockAcc(learners,[2:end-1]))./sqrt(25);

end


figure
subplot(1,4,1)
hold on;
errorbar(accMeans(1,:),accStderrs(1,:),'bd-');
errorbar(accMeans(2,:),accStderrs(2,:),'rs--');
axis([0 6 .4 1])
title('exp1 all participants');
ylabel('accuracy')
xlabel('bin')

subplot(1,4,2)
hold on;
errorbar(learnerAccMeans(1,:),learnerAccStderrs(1,:),'bd-');
errorbar(learnerAccMeans(2,:),learnerAccStderrs(2,:),'rs--');
axis([0 6 .4 1])
title('exp1 learners only');
ylabel('accuracy')
xlabel('bin')

subplot(1,4,3)
hold on;
errorbar(accMeans(3,:),accStderrs(3,:),'bd-');
errorbar(accMeans(4,:),accStderrs(4,:),'rs--');
axis([0 6 .4 1])
title('exp2 all participants');
ylabel('accuracy')
xlabel('bin')

subplot(1,4,4)
hold on;
errorbar(learnerAccMeans(3,:),learnerAccStderrs(3,:),'bd-');
errorbar(learnerAccMeans(4,:),learnerAccStderrs(4,:),'rs--');
axis([0 6 .4 1])
title('exp2 learners only');
ylabel('accuracy')
xlabel('bin')

clear i sid S c p1 p2 p3 p4 pGrid c1 c2 c3 c4 cGrid
